Cassowary
=========

A pure Python implementation of the `Cassowary constraint-solving algorithm`_.
Cassowary is the algorithm that forms the core of the OS X and iOS visual
layout mechanism.

.. _Cassowary constraint-solving algorithm: http://www.cs.washington.edu/research/constraints/cassowary/

Quickstart
----------

Cassowary is compatible with both Python 2 or Python 3. To install Cassowary
in your virtualenv, run::

    $ pip install cassowary

Then, in your Python code, you can create and solve constraint systems. See
`the documentation`_ for examples of what this looks like in
practice.

.. _the documentation: http://cassowary.readthedocs.org/en/latest/topics/examples.html

Documentation
-------------

Documentation for Cassowary can be found on `Read The Docs`_.

Community
---------

Cassowary is part of the `BeeWare suite`_. You can talk to the community through:

 * `@pybeeware on Twitter`_

 * The `BeeWare Users Mailing list`_, for questions about how to use the BeeWare suite.

 * The `BeeWare Developers Mailing list`_, for discussing the development of new features in the BeeWare suite, and ideas for new tools for the suite.

Contributing
------------

If you experience problems with Cassowary, `log them on GitHub`_. If you
want to contribute code, please `fork the code`_ and `submit a pull request`_.

.. _BeeWare suite: http://pybee.org
.. _Read The Docs: http://cassowary.readthedocs.org
.. _@pybeeware on Twitter: https://twitter.com/pybeeware
.. _BeeWare Users Mailing list: https://groups.google.com/forum/#!forum/beeware-users
.. _BeeWare Developers Mailing list: https://groups.google.com/forum/#!forum/beeware-developers
.. _log them on Github: https://github.com/pybee/cassowary/issues
.. _fork the code: https://github.com/pybee/cassowary
.. _submit a pull request: https://github.com/pybee/cassowary/pulls
